==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/enums/RosettaNetPipActivityType.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * The RosettaNet ProcessConfiguration activity type.
 */
public enum class RosettaNetPipActivityType(
    public val javaValue: com.pulumi.azurenative.logic.enums.RosettaNetPipActivityType,
) : ConvertibleToJava<com.pulumi.azurenative.logic.enums.RosettaNetPipActivityType> {
    NotSpecified(com.pulumi.azurenative.logic.enums.RosettaNetPipActivityType.NotSpecified),
    InformationDistribution(com.pulumi.azurenative.logic.enums.RosettaNetPipActivityType.InformationDistribution),
    BusinessTransaction(com.pulumi.azurenative.logic.enums.RosettaNetPipActivityType.BusinessTransaction),
    Notification(com.pulumi.azurenative.logic.enums.RosettaNetPipActivityType.Notification),
    QueryResponse(com.pulumi.azurenative.logic.enums.RosettaNetPipActivityType.QueryResponse),
    RequestConfirm(com.pulumi.azurenative.logic.enums.RosettaNetPipActivityType.RequestConfirm),
    RequestResponse(com.pulumi.azurenative.logic.enums.RosettaNetPipActivityType.RequestResponse),
    ;

    override fun toJava(): com.pulumi.azurenative.logic.enums.RosettaNetPipActivityType = javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.logic.enums.RosettaNetPipActivityType):
            RosettaNetPipActivityType =
            RosettaNetPipActivityType.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/logic/kotlin/enums/RosettaNetPipActivityType.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * The RosettaNet ProcessConfiguration activity type.
 */
public enum class RosettaNetPipActivityType(
    public val javaValue: com.pulumi.azurenative.logic.enums.RosettaNetPipActivityType,
) : ConvertibleToJava<com.pulumi.azurenative.logic.enums.RosettaNetPipActivityType> {
    NotSpecified(com.pulumi.azurenative.logic.enums.RosettaNetPipActivityType.NotSpecified),
    InformationDistribution(com.pulumi.azurenative.logic.enums.RosettaNetPipActivityType.InformationDistribution),
    BusinessTransaction(com.pulumi.azurenative.logic.enums.RosettaNetPipActivityType.BusinessTransaction),
    Notification(com.pulumi.azurenative.logic.enums.RosettaNetPipActivityType.Notification),
    QueryResponse(com.pulumi.azurenative.logic.enums.RosettaNetPipActivityType.QueryResponse),
    RequestConfirm(com.pulumi.azurenative.logic.enums.RosettaNetPipActivityType.RequestConfirm),
    RequestResponse(com.pulumi.azurenative.logic.enums.RosettaNetPipActivityType.RequestResponse),
    ;

    override fun toJava(): com.pulumi.azurenative.logic.enums.RosettaNetPipActivityType = javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.logic.enums.RosettaNetPipActivityType): RosettaNetPipActivityType =
            RosettaNetPipActivityType.values().first { it.javaValue == javaType }
    }
}
